@@ -1,12 +1,14 @@
+/* SPDX-License-Identifier: BSD-3-Clause */
+
 #include <stdio.h>
 #include "subid.h"
 #include "stdlib.h"
 #include "prototypes.h"
+#include "shadowlog.h"
 
 const char *Prog;
-FILE *shadow_logfd = NULL;
 
-void usage(void)
+static void usage(void)
 {
 	fprintf(stderr, "Usage: [-g] %s subuid\n", Prog);
 	fprintf(stderr, "    list uids who own the given subuid\n");
@@ -20,7 +22,8 @@ int main(int argc, char *argv[])
 	uid_t *uids;
 
 	Prog = Basename (argv[0]);
-	shadow_logfd = stderr;
+	log_set_progname(Prog);
+	log_set_logfd(stderr);
 	if (argc < 2) {
 		usage();
 	}
