@@ -1,13 +1,15 @@
+/* SPDX-License-Identifier: BSD-3-Clause */
+
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 #include "subid.h"
 #include "prototypes.h"
+#include "shadowlog.h"
 
 const char *Prog;
-FILE *shadow_logfd = NULL;
 
-void usage(void)
+static void usage(void)
 {
 	fprintf(stderr, "Usage: %s [-g] user\n", Prog);
 	fprintf(stderr, "    list subuid ranges for user\n");
@@ -22,7 +24,8 @@ int main(int argc, char *argv[])
 	const char *owner;
 
 	Prog = Basename (argv[0]);
-	shadow_logfd = stderr;
+	log_set_progname(Prog);
+	log_set_logfd(stderr);
 	if (argc < 2)
 		usage();
 	owner = argv[1];
